@@ -24,4 +24,4 @@ def test_suite():
     ])
 
 if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite') 
\ No newline at end of file
+    unittest.main(defaultTest='test_suite')                 #pragma NO COVERAGE
\ No newline at end of file
